package com.temboo.android.gettingstarted.app;

import android.os.AsyncTask;
import android.util.Log;
import android.webkit.WebView;

import com.temboo.Library.Facebook.OAuth.InitializeOAuth;
import com.temboo.Library.Facebook.OAuth.InitializeOAuth.*;
import com.temboo.Library.Facebook.OAuth.FinalizeOAuth;
import com.temboo.Library.Facebook.OAuth.FinalizeOAuth.*;
import com.temboo.Library.Facebook.Reading.User;
import com.temboo.Library.Facebook.Reading.User.*;


import com.temboo.core.TembooException;
import com.temboo.core.TembooSession;

import java.security.SecureRandom;

/**
 * An AsyncTask that will be used to retrieve and display video query
 * results from Youtube.
 */
class FacebookOAuthHelper {

    private String accessToken;
    private String forwardingURL;
    private String stateToken;
    private TembooSession session;
    private WebView webView;

    private final static String FACEBOOK_APP_ID = "YOUR_FACEBOOK_APP_ID";
    private final static String FACEBOOK_APP_SECRET = "YOUR_FACEBOOK_APP_SECRET";

    private final static String TEMBOO_ACCOUNT_NAME = "YOUR_ACCOUNT_NAME";
    private final static String TEMBOO_APPLICATION_NAME = "YOUR_APPLICATION_NAME";
    private final static String TEMBOO_APPLICATION_KEY = "YOUR_APPLICATION_KEY";

    public FacebookOAuthHelper(WebView webView, String forwardingURL) {
        this.forwardingURL = forwardingURL;
        this.webView = webView;

        // Initialize Temboo session
        try{
            session = new TembooSession(TEMBOO_ACCOUNT_NAME, TEMBOO_APPLICATION_NAME, TEMBOO_APPLICATION_KEY);
        }
        catch(TembooException te){
            Log.e("FacebookOAuthHelpder", te.getMessage());
        }

        // Generates a secure custom callback ID
        SecureRandom random = new SecureRandom();
        stateToken = "facebook-" + random.nextInt();
    }

    public void initOauth(){
        new FacebookInitOAuthTask().execute(null, null, null);
    }

    public void getUserInfo(){
        // Finalize OAuth, which in turn retrieves/displays the user's info via FacebookGetUserInfoTask
        new FacebookFinalizeOAuthTask().execute(null, null, null);
    }

    private class FacebookInitOAuthTask extends AsyncTask<Void, Void, String> {

        @Override
        protected String doInBackground(Void... params) {
            try {
                // Instantiate the InitializeOAuth choreo, using a session object.
                InitializeOAuth initializeOauthChoreo = new InitializeOAuth(session);

                // Get an input set for InitializeOAuth.
                InitializeOAuthInputSet initializeOauthInputs = initializeOauthChoreo.newInputSet();

                // Set inputs for InitializeOAuth, use a state token as the custom callback id
                initializeOauthInputs.set_AppID(FACEBOOK_APP_ID);
                initializeOauthInputs.set_CustomCallbackID(stateToken);
                initializeOauthInputs.set_ForwardingURL(forwardingURL);

                // Execute InitializeOAuth choreo.
                InitializeOAuthResultSet initializeOauthResults = initializeOauthChoreo.execute(initializeOauthInputs);

                // This is the URL that the user will be directed to in order to login to FB and allow access.
                return initializeOauthResults.get_AuthorizationURL();
            } catch(Exception e) {
                // if an exception occurred, log it
                Log.e(this.getClass().toString(), e.getMessage());
            }
            return null;
        }

        protected void onPostExecute(String authURL) {
            try {
                // Redirect the user to the authorization (Facebook) URL
                webView.loadUrl(authURL);
            } catch(Exception e) {
                // if an exception occurred, show an error message
                Log.e(this.getClass().toString(), e.getMessage());
            }
        }
    }

    private class FacebookFinalizeOAuthTask extends AsyncTask<Void, Void, String> {
        @Override
        protected String doInBackground(Void... params) {
            try {
                // Instantiate the FinalizeOAuth choreo, using a session object.
                FinalizeOAuth finalizeOauthChoreo = new FinalizeOAuth(session);
                FinalizeOAuthInputSet finalizeOauthInputs = finalizeOauthChoreo.newInputSet();

                // Set input for FinalizeOAuth choreo.
                finalizeOauthInputs.set_AppID(FACEBOOK_APP_ID);
                finalizeOauthInputs.set_AppSecret(FACEBOOK_APP_SECRET);
                finalizeOauthInputs.set_LongLivedToken("1");

                final String customCallbackID = TEMBOO_ACCOUNT_NAME + "/" + stateToken;
                finalizeOauthInputs.set_CallbackID(customCallbackID);

                // Execute FinalizeOAuth choreo and retrieve the access token
                FinalizeOAuthResultSet finalizeOauthResults = finalizeOauthChoreo.execute(finalizeOauthInputs);

                accessToken = finalizeOauthResults.get_AccessToken();

                return "Retrieved access token: " + accessToken;
            } catch(Exception e) {
                // if an exception occurred, log it
                Log.e(this.getClass().toString(), e.getMessage());
            }
            return null;
        }

        protected void onPostExecute(String accessToken) {
            try {
                new FacebookGetUserInfoTask().execute();
            } catch(Exception e) {
                // if an exception occurred, show an error message
                Log.e(this.getClass().toString(), e.getMessage());
            }
        }
    }

    private class FacebookGetUserInfoTask extends AsyncTask<Void, Void, String> {
        @Override
        protected String doInBackground(Void... params) {
            try {
                // Get user info. Instantiate the choreo, using a session object.
                User userChoreo = new User(session);

                // Get an InputSet object for the Facebook.Reading.User choreo.
                UserInputSet userInputs = userChoreo.newInputSet();

                // Pass access token to the Facebook.Reading.User choreo.
                userInputs.set_AccessToken(accessToken);

                // Execute Facebook.Reading.User choreo.
                UserResultSet userResults = userChoreo.execute(userInputs);

                return userResults.get_Response();
            } catch(Exception e) {
                // if an exception occurred, log it
                Log.e(this.getClass().toString(), e.getMessage());
            }
            return null;
        }

        protected void onPostExecute(String userInfo) {
            try {
                // Display user's account info
                webView.loadData(userInfo, "text/json", "utf-8");
            } catch(Exception e) {
                // if an exception occurred, show an error message
                Log.e(this.getClass().toString(), e.getMessage());
            }
        }
    }
}
