package com.temboo.Library.Facebook.Actions.News.Publishes;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DeletePublication

Deletes a given news publishing action.
*/
public class DeletePublication extends Choreography {

	/**
	Create a new instance of the DeletePublication Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DeletePublication(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Facebook/Actions/News/Publishes/DeletePublication"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DeletePublicationInputSet
	*/
	public DeletePublicationInputSet newInputSet() {
		return new DeletePublicationInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DeletePublicationResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DeletePublicationResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DeletePublication
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DeletePublicationInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved from the final step of the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ActionID input for this Choreo. 

		@param String - (required, string) The id of an action to delete.
		*/
		public void set_ActionID(String value) {
			this.setInput("ActionID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DeletePublication Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DeletePublicationResultSet extends ResultSet {
		public DeletePublicationResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (boolean) The response from Facebook. Returns "true" on success.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
