package com.temboo.Library.Facebook.Deleting;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Unlike

Allows a user to "unlike" a Graph API object.
*/
public class Unlike extends Choreography {

	/**
	Create a new instance of the Unlike Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Unlike(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Facebook/Deleting/Unlike"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UnlikeInputSet
	*/
	public UnlikeInputSet newInputSet() {
		return new UnlikeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UnlikeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UnlikeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Unlike
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UnlikeInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved from the final step of the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ObjectID input for this Choreo. 

		@param String - (required, string) The id of a graph api object to unlike.
		*/
		public void set_ObjectID(String value) {
			this.setInput("ObjectID", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Unlike Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UnlikeResultSet extends ResultSet {
		public UnlikeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (boolean) The response from Facebook. Returns "true" on success.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
