package com.temboo.Library.Facebook.Publishing;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
PublishNote

Publishes a note on a given profile.
*/
public class PublishNote extends Choreography {

	/**
	Create a new instance of the PublishNote Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public PublishNote(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Facebook/Publishing/PublishNote"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return PublishNoteInputSet
	*/
	public PublishNoteInputSet newInputSet() {
		return new PublishNoteInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public PublishNoteResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new PublishNoteResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the PublishNote
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class PublishNoteInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved from the final step of the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Message input for this Choreo. 

		@param String - (required, string) The contents of the note.
		*/
		public void set_Message(String value) {
			this.setInput("Message", value);
		}



		/** 
		Set the value of the ProfileID input for this Choreo. 

		@param String - (optional, string) The id of the profile that the note will be published to. Defaults to "me" indicating the authenticated user.
		*/
		public void set_ProfileID(String value) {
			this.setInput("ProfileID", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



		/** 
		Set the value of the Subject input for this Choreo. 

		@param String - (required, string) A subject line for the note being created.
		*/
		public void set_Subject(String value) {
			this.setInput("Subject", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the PublishNote Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class PublishNoteResultSet extends ResultSet {
		public PublishNoteResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Facebook. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
