package com.temboo.Library.Facebook.Reading;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetObject

Retrieves retrieves the details for a Graph API object that you specify.
*/
public class GetObject extends Choreography {

	/**
	Create a new instance of the GetObject Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetObject(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Facebook/Reading/GetObject"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetObjectInputSet
	*/
	public GetObjectInputSet newInputSet() {
		return new GetObjectInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetObjectResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetObjectResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetObject
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetObjectInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved from the final step of the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the Fields input for this Choreo. 

		@param String - (optional, string) A comma separated list of fields to return (i.e. id,name).
		*/
		public void set_Fields(String value) {
			this.setInput("Fields", value);
		}



		/** 
		Set the value of the ObjectID input for this Choreo. 

		@param String - (required, string) The id of a graph api object to retrieve.
		*/
		public void set_ObjectID(String value) {
			this.setInput("ObjectID", value);
		}



		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetObject Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetObjectResultSet extends ResultSet {
		public GetObjectResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Facebook.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
