package com.temboo.Library.Facebook.Reading;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Picture

Retrieves the current profile photo for any object in the Facebook graph, and returns the image as a Base64 encoded string.
*/
public class Picture extends Choreography {

	/**
	Create a new instance of the Picture Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Picture(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Facebook/Reading/Picture"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return PictureInputSet
	*/
	public PictureInputSet newInputSet() {
		return new PictureInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public PictureResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new PictureResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Picture
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class PictureInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved from the final step of the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}



		/** 
		Set the value of the ProfileID input for this Choreo. 

		@param String - (required, string) The id of the profile to retrieve a profile picture for. Defaults to "me" indicating the authenticated user.
		*/
		public void set_ProfileID(String value) {
			this.setInput("ProfileID", value);
		}



		/** 
		Set the value of the ReturnSSLResources input for this Choreo. 

		@param Boolean - (optional, boolean) Set to 1 to return the picture over a secure connection. Defaults to 0.
		*/
		public void set_ReturnSSLResources(Boolean value) {
			this.setInput("ReturnSSLResources", value);
		}

		/** 
		Set the value of the ReturnSSLResources input for this Choreo as a String. 

		@param String - (optional, boolean) Set to 1 to return the picture over a secure connection. Defaults to 0.
		*/
		public void set_ReturnSSLResources(String value) {
			this.setInput("ReturnSSLResources", value);	
		}

		/** 
		Set the value of the Type input for this Choreo. 

		@param String - (optional, string) The size of the image to retrieve. Valid values: square (50x50), small (50 pixels wide, variable height), normal (100 pixels wide, variable height), and large (about 200 pixels wide, variable height)
		*/
		public void set_Type(String value) {
			this.setInput("Type", value);
		}



	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Picture Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class PictureResultSet extends ResultSet {
		public PictureResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (string) Contains the Base64 encoded value of the image retrieved from Facebook.
		*/
		public String get_Response() {
			return this.getResult("Response");
		}
	}
	
}
